Crate rust_ipfs

Crate rust_ipfs 

IPFS node implementation

Ipfs is a peer-to-peer system with content addressed functionality. The main entry point for users of this crate is the Ipfs facade, which allows access to most of the implemented functionality.

This crate passes a lot of the interface-ipfs-core test suite; most of that functionality is in ipfs-http crate. The crate has some interoperability with the go-ipfs and js-ipfs implementations.

ipfs is an early alpha level crate: APIs and their implementation are subject to change in any upcoming release at least for now. The aim of the crate is to become a library-first production ready implementation of an Ipfs node.

Re-exports

pub use block::Block;
pub use self::p2p::BehaviourEvent;
pub use self::p2p::KadResult;
pub use self::path::IpfsPath;
pub use self::repo::PinKind;
pub use self::repo::PinMode;

Modules

block
builder
config
dag
ipfs.dag interface implementation around Ipfs.
dummy
error
Crate-wide errors.
gossipsub
identify
ipns
IPNS functionality around Ipfs.
p2p
P2P handling for IPFS nodes.
path
IpfsPath related functionality for content addressed paths with links.
ping
refs
refs or the references of dag-pb and other supported IPLD formats functionality.
repo
Storage implementation(s) backing the crate::Ipfs.
swarm
unixfs
Adaptation for ipfs-unixfs crate functionality on top of Ipfs.

Structs

AddPeerOpt
ConnectionId
Connection identifier.
ConnectionLimits
The configurable connection limits.
DialOpts
Options to configure a dial to a known or unknown peer.
Error
Just re-export anyhow for now.
GossipsubMessage
InboundRequestId
The ID of an inbound request.
Ipfs
The facade for the Ipfs node.
Keypair
Identity keypair of a node.
ListenerId
The ID of a single listener.
Multiaddr
Representation of a Multiaddr.
OptionalStreamProtocol
PeerId
Identifier of a peer of the network.
Record
A record stored in the DHT.
RecordKey
The (opaque) key of a record.
RequestResponseConfig
Stream
StreamProtocol
Identifies a protocol for a stream.

Enums

ConnectedPoint
The endpoint roles associated with an established peer-to-peer connection.
ConnectionEvent
DhtMode
FDLimit
Mode
PeerCondition
The available conditions under which a new dialing attempt to a known peer is initiated.
PeerConnectionEvents
Protocol
Protocol describes all possible multiaddress protocols.
PubsubEvent
Quorum
A quorum w.r.t. the configured replication factor specifies the minimum number of distinct nodes that must be successfully contacted in order for a query to succeed.
RepoProvider

Traits

IntoAddPeerOpt
IntoRequest
NetworkBehaviour
A NetworkBehaviour defines the behaviour of the local node on the network.
ToRecordKey

Derive Macros

NetworkBehaviour
Generates a delegating NetworkBehaviour implementation for the struct this is used for. See the trait documentation for better description.