IpfsBuilder

Struct IpfsBuilder 

pub struct IpfsBuilder<C: NetworkBehaviour<ToSwarm = Infallible> + Send + Sync + 'static> { /* private fields */ }
Configured Ipfs which can only be started.

Implementations

Source

impl<C: NetworkBehaviour<ToSwarm = Infallible> + Send + Sync + 'static> IpfsBuilder<C>

pub fn new() -> Self

New uninitualized instance

pub fn with_keypair(keypair: impl IntoKeypair) -> Result<Self>

New instance with an existing keypair

pub fn set_default_listener(self) -> Self

Set default listening unspecified ipv4 and ipv6 addresses for tcp and quic Note that this still requires for the transports to be enabled to be usable

pub fn add_listening_addr(self, addr: Multiaddr) -> Self

Adds a listening address

pub fn set_connection_limits<F>(self, f: F) -> Self
where F: Fn(ConnectionLimits) -> ConnectionLimits + Send + Sync + 'static,

Set a connection limit

pub fn add_listening_addrs(self, addrs: Vec<Multiaddr>) -> Self

Adds a listening addresses

pub fn set_listening_addrs(self, addrs: Vec<Multiaddr>) -> Self

Set a list of listening addresses

pub fn add_bootstrap(self, addr: Multiaddr) -> Self

Adds a bootstrap node

pub fn with_default(self) -> Self

Load default behaviour for basic functionality

pub fn with_kademlia(self) -> Self

Enables kademlia

pub fn with_bitswap(self) -> Self

Enables bitswap

pub fn with_mdns(self) -> Self

Enable mdns

pub fn with_relay(self, with_dcutr: bool) -> Self

Enable relay client

pub fn with_relay_server(self, config: RelayConfig) -> Self

Enable relay server

pub fn with_upnp(self) -> Self

Enable port mapping (AKA UPnP)

pub fn with_rendezvous_server(self) -> Self

Enables rendezvous server

pub fn with_rendezvous_client(self) -> Self

Enables rendezvous client

pub fn with_identify(self, config: IdentifyConfiguration) -> Self

Enables identify

pub fn with_streams(self) -> Self

pub fn with_pubsub(self, config: PubsubConfig) -> Self

Enables pubsub

pub fn with_request_response(self, config: Vec<RequestResponseConfig>) -> Self

Enables request response. Note: At this time, this option will only support up to 10 request-response behaviours. with any additional being ignored. Additionally, any duplicated protocols that are provided will be ignored.

pub fn with_autonat(self) -> Self

Enables autonat

pub fn with_ping(self, config: Config) -> Self

Enables ping

pub fn with_custom_behaviour<F>(self, f: F) -> Self
where F: FnOnce(&Keypair) -> Result<C> + 'static,

Set a custom behaviour

pub fn with_gc(self, config: GCConfig) -> Self

Enables automatic garbage collection

pub fn set_temp_pin_duration(self, duration: Duration) -> Self

Set a duration for which blocks are not removed due to the garbage collector Defaults: 2 mins

pub fn set_path<P: AsRef<Path>>(self, path: P) -> Self

Sets a path

pub fn set_idle_connection_timeout(self, duration: u64) -> Self

Set timeout for idle connections

pub fn set_swarm_configuration<F>(self, f: F) -> Self
where F: FnOnce(Config) -> Config + Send + Sync + 'static,

Set swarm configuration

pub fn default_record_key_validator(self) -> Self

Set default record validator for IPFS Note: This will override any keys set for ipns prefix

pub fn set_record_prefix_validator<F>(self, key: &str, callback: F) -> Self
where F: Fn(&str) -> Result<RecordKey> + Sync + Send + 'static,

pub fn set_addrbook_configuration(self, config: AddressBookConfig) -> Self

Set address book configuration

pub fn set_provider(self, opt: RepoProvider) -> Self

Set RepoProvider option to provide blocks automatically

pub fn set_repo(self, repo: &Repo<DefaultStorage>) -> Self

Set block and data repo

pub fn set_keystore(self, keystore: &Keystore) -> Self

Set a keystore

pub fn enable_quic(self) -> Self

Enables quic transport

pub fn enable_quic_with_config<F>(self, f: F) -> Self
where F: FnOnce(Config) -> Config + 'static,

Enables quic transport with custom configuration

pub fn enable_tcp(self) -> Self

Enables tcp transport

pub fn enable_tcp_with_config<F>(self, f: F) -> Self
where F: FnOnce(Config) -> Config + 'static,

Enables tcp transport with custom configuration

pub fn enable_websocket(self) -> Self

Enables websocket transport

pub fn enable_secure_websocket(self) -> Self

Enables secure websocket transport

pub fn enable_secure_websocket_with_pem( self, keypair: String, certs: Vec<String>, ) -> Self

Enables secure websocket transport

pub fn enable_secure_websocket_with_config<F>(self, f: F) -> Result<Self>
where F: FnOnce(&Keypair) -> Result<(Vec<String>, String)>,

Enables secure websocket transport

pub fn enable_dns(self) -> Self

Enables DNS

pub fn enable_dns_with_resolver(self, resolver: DnsResolver) -> Self

Enables DNS with a specific resolver

pub fn enable_memory_transport(self) -> Self

Enables memory transport

pub fn fd_limit(self, limit: FDLimit) -> Self

Set file desc limit

pub fn set_span(self, span: Span) -> Self

Set tracing span

pub fn swarm_events<F>(self, func: F) -> Self
where F: Fn(&mut Swarm<Behaviour<Behaviour<C>, MemoryStore>>, &<Swarm<Behaviour<Behaviour<C>, MemoryStore>> as Stream>::Item) + Sync + Send + 'static,

Handle libp2p swarm events

pub async fn start(self) -> Result<Ipfs, Error>

Initialize the ipfs node. The returned Ipfs value is cloneable, send and sync.