Module path

Module path 

IpfsPath related functionality for content addressed paths with links.

Structs

IpfsPath
Abstraction over Ipfs paths, which are used to target sub-trees or sub-documents on top of content addressable (Cid) trees. The most common use case is to specify a file under an unixfs tree from underneath a Cid forest.
SlashedPath
SlashedPath is internal to IpfsPath variants, and basically holds a unixfs-compatible path where segments do not contain slashes but can pretty much contain all other valid UTF-8.

Enums

IpfsPathError
The path mutation or parsing errors.
PathRoot
The “protocol” of IpfsPath.