pub enum RepoEvent {
WantBlock(Vec<Cid>, Vec<PeerId>, Option<Duration>),
UnwantBlock(Cid),
NewBlock(Block),
RemovedBlock(Cid),
}Expand description
Events used to communicate to the swarm on repo changes.
Variants
WantBlock(Vec<Cid>, Vec<PeerId>, Option<Duration>)
Signals desired blocks.
UnwantBlock(Cid)
Signals that a waiter for the cid went away; the cid should be re-evaluated for cancellation against the (authoritative) subscriptions map.
NewBlock(Block)
Signals the posession of a new block.
RemovedBlock(Cid)
Signals the removal of a block.