pub struct DefaultStorage { /* private fields */ }Trait Implementations
Sourceimpl BlockStore for DefaultStorage
impl BlockStore for DefaultStorage
async fn init(&self) -> Result<(), Error>
Sourceasync fn contains(&self, cid: &Cid) -> Result<bool, Error>
async fn contains(&self, cid: &Cid) -> Result<bool, Error>
Returns whether a block is present in the blockstore.
Sourceasync fn get(&self, cid: &Cid) -> Result<Option<Block>, Error>
async fn get(&self, cid: &Cid) -> Result<Option<Block>, Error>
Returns a block from the blockstore.
Sourceasync fn size(&self, cid: &[Cid]) -> Result<Option<usize>, Error>
async fn size(&self, cid: &[Cid]) -> Result<Option<usize>, Error>
Get the size of a single block
Sourceasync fn put(&self, block: &Block) -> Result<(Cid, BlockPut), Error>
async fn put(&self, block: &Block) -> Result<(Cid, BlockPut), Error>
Inserts a block in the blockstore.
Sourceimpl Clone for DefaultStorage
impl Clone for DefaultStorage
Sourceimpl DataStore for DefaultStorage
impl DataStore for DefaultStorage
async fn init(&self) -> Result<(), Error>
Sourceasync fn contains(&self, key: &[u8]) -> Result<bool, Error>
async fn contains(&self, key: &[u8]) -> Result<bool, Error>
Checks if a key is present in the datastore.
Sourceasync fn get(&self, key: &[u8]) -> Result<Option<Vec<u8>>, Error>
async fn get(&self, key: &[u8]) -> Result<Option<Vec<u8>>, Error>
Returns the value associated with a key from the datastore.
Sourceasync fn put(&self, key: &[u8], value: &[u8]) -> Result<(), Error>
async fn put(&self, key: &[u8], value: &[u8]) -> Result<(), Error>
Puts the value under the key in the datastore.
Sourceimpl Debug for DefaultStorage
impl Debug for DefaultStorage
Sourceimpl Default for DefaultStorage
impl Default for DefaultStorage
Sourceimpl Lock for DefaultStorage
impl Lock for DefaultStorage
Sourceimpl PinStore for DefaultStorage
impl PinStore for DefaultStorage
async fn is_pinned(&self, block: &Cid) -> Result<bool, Error>
async fn insert_direct_pin(&self, target: &Cid) -> Result<(), Error>
async fn insert_recursive_pin( &self, target: &Cid, referenced: BoxStream<'_, Result<Cid, IpldRefsError>>, ) -> Result<(), Error>
async fn remove_direct_pin(&self, target: &Cid) -> Result<(), Error>
async fn remove_recursive_pin( &self, target: &Cid, referenced: BoxStream<'_, Result<Cid, IpldRefsError>>, ) -> Result<(), Error>
async fn list( &self, mode: Option<PinMode>, ) -> BoxStream<'static, Result<(Cid, PinMode), Error>>
Sourceimpl RepoTypes for DefaultStorage
impl RepoTypes for DefaultStorage
Sourcetype TBlockStore = DefaultStorage
type TBlockStore = DefaultStorage
Describes a blockstore.
Sourcetype TDataStore = DefaultStorage
type TDataStore = DefaultStorage
Describes a datastore.
type TLock = DefaultStorage
impl Unpin for DefaultStorage