pub struct RepoInsertPin<S: RepoTypes> { /* private fields */ }Implementations
Sourceimpl<S: RepoTypes> RepoInsertPin<S>
impl<S: RepoTypes> RepoInsertPin<S>
pub fn new<C: Borrow<Cid>>(repo: Repo<S>, cid: C) -> Self
Sourcepub fn providers(self, providers: &[PeerId]) -> Self
pub fn providers(self, providers: &[PeerId]) -> Self
List of peers that may contain the block to pin
Sourcepub fn timeout(self, duration: Duration) -> Self
pub fn timeout(self, duration: Duration) -> Self
Duration to fetch the block from the network before timing out
pub fn exit_on_error(self) -> Self