pub struct RequestResponseConfig {
pub protocol: String,
pub timeout: Option<Duration>,
pub max_request_size: usize,
pub max_response_size: usize,
pub concurrent_streams: Option<usize>,
pub channel_buffer: usize,
pub protocol_direction: RequestResponseDirection,
}Fields
protocol: Stringtimeout: Option<Duration>max_request_size: usizemax_response_size: usizeconcurrent_streams: Option<usize>channel_buffer: usizeprotocol_direction: RequestResponseDirectionImplementations
Sourceimpl RequestResponseConfig
impl RequestResponseConfig
pub fn new(protocol: impl Into<String>) -> RequestResponseConfig
Sourcepub fn set_timeout(self, timeout: Duration) -> RequestResponseConfig
pub fn set_timeout(self, timeout: Duration) -> RequestResponseConfig
Set a duration which would indicate on how long it should take for a response before the request times out.
Sourcepub fn set_max_request_size(self, size: usize) -> RequestResponseConfig
pub fn set_max_request_size(self, size: usize) -> RequestResponseConfig
Set the maximum size of a request.
Sourcepub fn set_max_response_size(self, size: usize) -> RequestResponseConfig
pub fn set_max_response_size(self, size: usize) -> RequestResponseConfig
Set the maximum size of a response.
Sourcepub fn set_concurrent_streams(self, size: usize) -> RequestResponseConfig
pub fn set_concurrent_streams(self, size: usize) -> RequestResponseConfig
Set the upper bound of inbound and outbound streams.
Sourcepub fn set_channel_buffer(self, size: usize) -> RequestResponseConfig
pub fn set_channel_buffer(self, size: usize) -> RequestResponseConfig
Set the max slot available to send requests over channels.
pub fn set_protocol_direction( self, direction: RequestResponseDirection, ) -> RequestResponseConfig