pub enum DialError {
LocalPeerId {
address: Multiaddr,
},
NoAddresses,
DialPeerConditionFalse(PeerCondition),
Aborted,
WrongPeerId {
obtained: PeerId,
address: Multiaddr,
},
Denied {
cause: ConnectionDenied,
},
Transport(Vec<(Multiaddr, TransportError<Error>)>),
}Expand description
Possible errors when trying to establish or upgrade an outbound connection.
Variants
LocalPeerId
The peer identity obtained on the connection matches the local peer.
NoAddresses
No addresses have been provided by NetworkBehaviour::handle_pending_outbound_connection
and DialOpts.
DialPeerConditionFalse(PeerCondition)
The provided dial_opts::PeerCondition evaluated to false and thus
the dial was aborted.
Aborted
Pending connection attempt has been aborted.
WrongPeerId
The peer identity obtained on the connection did not match the one that was expected.
Denied
One of the NetworkBehaviours rejected the outbound connection
via NetworkBehaviour::handle_pending_outbound_connection or
NetworkBehaviour::handle_established_outbound_connection.
Fields
cause: ConnectionDeniedTransport(Vec<(Multiaddr, TransportError<Error>)>)
An error occurred while negotiating the transport protocol(s) on a connection.