pub enum StreamUpgradeError<TUpgrErr> {
Timeout,
Apply(TUpgrErr),
NegotiationFailed,
Io(Error),
}Expand description
Error that can happen on an outbound substream opening attempt.
Variants
Timeout
The opening attempt timed out before the negotiation was fully completed.
Apply(TUpgrErr)
The upgrade produced an error.
NegotiationFailed
No protocol could be agreed upon.
Io(Error)
An IO or otherwise unrecoverable error happened.
Implementations
Sourceimpl<TUpgrErr> StreamUpgradeError<TUpgrErr>
impl<TUpgrErr> StreamUpgradeError<TUpgrErr>
Sourcepub fn map_upgrade_err<F, E>(self, f: F) -> StreamUpgradeError<E>where
F: FnOnce(TUpgrErr) -> E,
pub fn map_upgrade_err<F, E>(self, f: F) -> StreamUpgradeError<E>where
F: FnOnce(TUpgrErr) -> E,
Map the inner StreamUpgradeError type.