pub struct DuplicateProtonameError(/* private fields */);Expand description
It is an error if two handlers share the same protocol name.
Implementations
Sourceimpl DuplicateProtonameError
impl DuplicateProtonameError
Sourcepub fn protocol_name(&self) -> &[u8] ⓘ
pub fn protocol_name(&self) -> &[u8] ⓘ
The protocol name bytes that occurred in more than one handler.