SwarmBuilder

Struct SwarmBuilder 

pub struct SwarmBuilder<Provider, Phase> { /* private fields */ }
Build a Swarm by combining an identity, a set of Transports and a NetworkBehaviour.


let swarm = SwarmBuilder::with_new_identity()
    .with_tokio()
    .with_tcp(
        Default::default(),
        (libp2p_tls::Config::new, libp2p_noise::Config::new),
        libp2p_yamux::Config::default,
    )?
    .with_quic()
    .with_other_transport(|_key| DummyTransport::<(PeerId, StreamMuxerBox)>::new())?
    .with_dns()?
    .with_websocket(
        (libp2p_tls::Config::new, libp2p_noise::Config::new),
        libp2p_yamux::Config::default,
    )
    .await?
    .with_relay_client(
        (libp2p_tls::Config::new, libp2p_noise::Config::new),
        libp2p_yamux::Config::default,
    )?
    .with_behaviour(|_key, relay| MyBehaviour { relay })?
    .with_swarm_config(|cfg| {
        // Edit cfg here.
        cfg
    })
    .build();

Implementations

Source

impl<T, Provider, R> SwarmBuilder<Provider, BandwidthMetricsPhase<T, R>>

pub fn without_bandwidth_metrics( self, ) -> SwarmBuilder<Provider, BehaviourPhase<T, R>>

Source

impl<Provider, T> SwarmBuilder<Provider, BandwidthMetricsPhase<T, Behaviour>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_behaviour<B, R>( self, constructor: impl FnOnce(&Keypair, Behaviour) -> R, ) -> Result<SwarmBuilder<Provider, SwarmPhase<T, B>>, <R as TryIntoBehaviour<B>>::Error>
where R: TryIntoBehaviour<B>,

Source

impl<Provider, T> SwarmBuilder<Provider, BandwidthMetricsPhase<T, NoRelayBehaviour>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_behaviour<B, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, SwarmPhase<T, B>>, <R as TryIntoBehaviour<B>>::Error>
where R: TryIntoBehaviour<B>,

Source

impl<T, Provider> SwarmBuilder<Provider, BehaviourPhase<T, Behaviour>>

pub fn with_behaviour<B, R>( self, constructor: impl FnOnce(&Keypair, Behaviour) -> R, ) -> Result<SwarmBuilder<Provider, SwarmPhase<T, B>>, <R as TryIntoBehaviour<B>>::Error>
where R: TryIntoBehaviour<B>,

Source

impl<T, Provider> SwarmBuilder<Provider, BehaviourPhase<T, NoRelayBehaviour>>

pub fn with_behaviour<B, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, SwarmPhase<T, B>>, <R as TryIntoBehaviour<B>>::Error>
where R: TryIntoBehaviour<B>,

Source

impl<Provider, T, B> SwarmBuilder<Provider, BuildPhase<T, B>>
where T: AuthenticatedMultiplexedTransport, B: NetworkBehaviour,

pub fn with_connection_timeout( self, connection_timeout: Duration, ) -> SwarmBuilder<Provider, BuildPhase<T, B>>

Timeout of the TransportTimeout wrapping the transport.

pub fn build(self) -> Swarm<B>

Source

impl<T> SwarmBuilder<Tokio, DnsPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_dns( self, ) -> Result<SwarmBuilder<Tokio, WebsocketPhase<impl AuthenticatedMultiplexedTransport>>, Error>

Source

impl<T> SwarmBuilder<Tokio, DnsPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_dns_config( self, cfg: ResolverConfig, opts: ResolverOpts, ) -> SwarmBuilder<Tokio, WebsocketPhase<impl AuthenticatedMultiplexedTransport>>

Source

impl<Provider, T> SwarmBuilder<Provider, DnsPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_behaviour<B, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, SwarmPhase<T, B>>, <R as TryIntoBehaviour<B>>::Error>
where R: TryIntoBehaviour<B>,

Source

impl SwarmBuilder<NoProviderSpecified, IdentityPhase>

pub fn with_new_identity() -> SwarmBuilder<NoProviderSpecified, ProviderPhase>

pub fn with_existing_identity( keypair: Keypair, ) -> SwarmBuilder<NoProviderSpecified, ProviderPhase>

Source

impl<Provider, T> SwarmBuilder<Provider, OtherTransportPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_other_transport<Muxer, OtherTransport, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, OtherTransportPhase<impl AuthenticatedMultiplexedTransport>>, <R as TryIntoTransport<OtherTransport>>::Error>
where Muxer: StreamMuxer + Send + 'static, OtherTransport: Transport<Output = (PeerId, Muxer)> + Send + Unpin + 'static, R: TryIntoTransport<OtherTransport>, <OtherTransport as Transport>::Error: Send + Sync + 'static, <OtherTransport as Transport>::Dial: Send, <OtherTransport as Transport>::ListenerUpgrade: Send, <Muxer as StreamMuxer>::Substream: Send, <Muxer as StreamMuxer>::Error: Send + Sync,

Source

impl<T> SwarmBuilder<Tokio, OtherTransportPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_dns( self, ) -> Result<SwarmBuilder<Tokio, WebsocketPhase<impl AuthenticatedMultiplexedTransport>>, Error>

Source

impl<T> SwarmBuilder<Tokio, OtherTransportPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_dns_config( self, cfg: ResolverConfig, opts: ResolverOpts, ) -> SwarmBuilder<Tokio, WebsocketPhase<impl AuthenticatedMultiplexedTransport>>

Source

impl<T, Provider> SwarmBuilder<Provider, OtherTransportPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_relay_client<SecUpgrade, SecStream, SecError, MuxUpgrade, MuxStream, MuxError>( self, security_upgrade: SecUpgrade, multiplexer_upgrade: MuxUpgrade, ) -> Result<SwarmBuilder<Provider, BandwidthMetricsPhase<impl AuthenticatedMultiplexedTransport, Behaviour>>, <SecUpgrade as IntoSecurityUpgrade<Connection>>::Error>
where SecStream: AsyncRead + AsyncWrite + Unpin + Send + 'static, SecError: Error + Send + Sync + 'static, SecUpgrade: IntoSecurityUpgrade<Connection>, <SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade: InboundConnectionUpgrade<Negotiated<Connection>, Output = (PeerId, SecStream), Error = SecError> + OutboundConnectionUpgrade<Negotiated<Connection>, Output = (PeerId, SecStream), Error = SecError> + Clone + Send + 'static, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as InboundConnectionUpgrade<Negotiated<Connection>>>::Future: Send, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as OutboundConnectionUpgrade<Negotiated<Connection>>>::Future: Send, <<<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as UpgradeInfo>::Info: Send, MuxStream: StreamMuxer + Send + 'static, <MuxStream as StreamMuxer>::Substream: Send + 'static, <MuxStream as StreamMuxer>::Error: Send + Sync + 'static, MuxUpgrade: IntoMultiplexerUpgrade<SecStream>, <MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade: InboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + OutboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + Clone + Send + 'static, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as InboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as OutboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, MuxError: Error + Send + Sync + 'static, <<<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::Info: Send,

Source

impl<Provider, T> SwarmBuilder<Provider, OtherTransportPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_behaviour<B, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, SwarmPhase<T, B>>, <R as TryIntoBehaviour<B>>::Error>
where R: TryIntoBehaviour<B>,

Source

impl SwarmBuilder<NoProviderSpecified, ProviderPhase>

pub fn with_tokio(self) -> SwarmBuilder<Tokio, TcpPhase>

Configures the SwarmBuilder to use the Tokio runtime. This method is only available when compiling for non-Wasm targets with the tokio feature enabled

Source

impl<T> SwarmBuilder<Tokio, QuicPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_quic( self, ) -> SwarmBuilder<Tokio, OtherTransportPhase<impl AuthenticatedMultiplexedTransport>>

pub fn with_quic_config( self, constructor: impl FnOnce(Config) -> Config, ) -> SwarmBuilder<Tokio, OtherTransportPhase<impl AuthenticatedMultiplexedTransport>>

Source

impl<Provider, T> SwarmBuilder<Provider, QuicPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_relay_client<SecUpgrade, SecStream, SecError, MuxUpgrade, MuxStream, MuxError>( self, security_upgrade: SecUpgrade, multiplexer_upgrade: MuxUpgrade, ) -> Result<SwarmBuilder<Provider, BandwidthMetricsPhase<impl AuthenticatedMultiplexedTransport, Behaviour>>, <SecUpgrade as IntoSecurityUpgrade<Connection>>::Error>
where SecStream: AsyncRead + AsyncWrite + Unpin + Send + 'static, SecError: Error + Send + Sync + 'static, SecUpgrade: IntoSecurityUpgrade<Connection>, <SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade: InboundConnectionUpgrade<Negotiated<Connection>, Output = (PeerId, SecStream), Error = SecError> + OutboundConnectionUpgrade<Negotiated<Connection>, Output = (PeerId, SecStream), Error = SecError> + Clone + Send + 'static, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as InboundConnectionUpgrade<Negotiated<Connection>>>::Future: Send, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as OutboundConnectionUpgrade<Negotiated<Connection>>>::Future: Send, <<<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as UpgradeInfo>::Info: Send, MuxStream: StreamMuxer + Send + 'static, <MuxStream as StreamMuxer>::Substream: Send + 'static, <MuxStream as StreamMuxer>::Error: Send + Sync + 'static, MuxUpgrade: IntoMultiplexerUpgrade<SecStream>, <MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade: InboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + OutboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + Clone + Send + 'static, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as InboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as OutboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, MuxError: Error + Send + Sync + 'static, <<<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::Info: Send,

pub fn with_other_transport<Muxer, OtherTransport, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, OtherTransportPhase<impl AuthenticatedMultiplexedTransport>>, <R as TryIntoTransport<OtherTransport>>::Error>
where Muxer: StreamMuxer + Send + 'static, OtherTransport: Transport<Output = (PeerId, Muxer)> + Send + Unpin + 'static, R: TryIntoTransport<OtherTransport>, <OtherTransport as Transport>::Error: Send + Sync + 'static, <OtherTransport as Transport>::Dial: Send, <OtherTransport as Transport>::ListenerUpgrade: Send, <Muxer as StreamMuxer>::Substream: Send, <Muxer as StreamMuxer>::Error: Send + Sync,

pub fn with_behaviour<B, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, SwarmPhase<T, B>>, <R as TryIntoBehaviour<B>>::Error>
where R: TryIntoBehaviour<B>,

Source

impl<T> SwarmBuilder<Tokio, QuicPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_dns( self, ) -> Result<SwarmBuilder<Tokio, WebsocketPhase<impl AuthenticatedMultiplexedTransport>>, Error>

Source

impl<T> SwarmBuilder<Tokio, QuicPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_dns_config( self, cfg: ResolverConfig, opts: ResolverOpts, ) -> SwarmBuilder<Tokio, WebsocketPhase<impl AuthenticatedMultiplexedTransport>>

Source

impl<T> SwarmBuilder<Tokio, QuicPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub async fn with_websocket<SecUpgrade, SecStream, SecError, MuxUpgrade, MuxStream, MuxError>( self, security_upgrade: SecUpgrade, multiplexer_upgrade: MuxUpgrade, ) -> Result<SwarmBuilder<Tokio, RelayPhase<impl AuthenticatedMultiplexedTransport>>, WebsocketError<<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Error>>
where SecStream: AsyncRead + AsyncWrite + Unpin + Send + 'static, SecError: Error + Send + Sync + 'static, SecUpgrade: IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>, <SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade: InboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>, Output = (PeerId, SecStream), Error = SecError> + OutboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>, Output = (PeerId, SecStream), Error = SecError> + Clone + Send + 'static, <<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as InboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>>>::Future: Send, <<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as OutboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>>>::Future: Send, <<<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as UpgradeInfo>::Info: Send, MuxStream: StreamMuxer + Send + 'static, <MuxStream as StreamMuxer>::Substream: Send + 'static, <MuxStream as StreamMuxer>::Error: Send + Sync + 'static, MuxUpgrade: IntoMultiplexerUpgrade<SecStream>, <MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade: InboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + OutboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + Clone + Send + 'static, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as InboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as OutboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, MuxError: Error + Send + Sync + 'static, <<<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::Info: Send,

Source

impl<Provider, T> SwarmBuilder<Provider, RelayPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_relay_client<SecUpgrade, SecStream, SecError, MuxUpgrade, MuxStream, MuxError>( self, security_upgrade: SecUpgrade, multiplexer_upgrade: MuxUpgrade, ) -> Result<SwarmBuilder<Provider, BandwidthMetricsPhase<impl AuthenticatedMultiplexedTransport, Behaviour>>, <SecUpgrade as IntoSecurityUpgrade<Connection>>::Error>
where SecStream: AsyncRead + AsyncWrite + Unpin + Send + 'static, SecError: Error + Send + Sync + 'static, SecUpgrade: IntoSecurityUpgrade<Connection>, <SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade: InboundConnectionUpgrade<Negotiated<Connection>, Output = (PeerId, SecStream), Error = SecError> + OutboundConnectionUpgrade<Negotiated<Connection>, Output = (PeerId, SecStream), Error = SecError> + Clone + Send + 'static, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as InboundConnectionUpgrade<Negotiated<Connection>>>::Future: Send, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as OutboundConnectionUpgrade<Negotiated<Connection>>>::Future: Send, <<<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as UpgradeInfo>::Info: Send, MuxStream: StreamMuxer + Send + 'static, <MuxStream as StreamMuxer>::Substream: Send + 'static, <MuxStream as StreamMuxer>::Error: Send + Sync + 'static, MuxUpgrade: IntoMultiplexerUpgrade<SecStream>, <MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade: InboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + OutboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + Clone + Send + 'static, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as InboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as OutboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, MuxError: Error + Send + Sync + 'static, <<<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::Info: Send,

Adds a relay client transport.

Note that both security_upgrade and multiplexer_upgrade take function pointers, i.e. they take the function themselves (without the invocation via ()), not the result of the function invocation. See example below.

let swarm = SwarmBuilder::with_new_identity()
    .with_tokio()
    .with_tcp(
        Default::default(),
        (libp2p_tls::Config::new, libp2p_noise::Config::new),
        libp2p_yamux::Config::default,
    )?
     .with_relay_client(
         (libp2p_tls::Config::new, libp2p_noise::Config::new),
         libp2p_yamux::Config::default,
     )?
Source

impl<Provider, T> SwarmBuilder<Provider, RelayPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_behaviour<B, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, SwarmPhase<T, B>>, <R as TryIntoBehaviour<B>>::Error>
where R: TryIntoBehaviour<B>,

Source

impl<T, B> SwarmBuilder<Tokio, SwarmPhase<T, B>>

pub fn with_swarm_config( self, constructor: impl FnOnce(Config) -> Config, ) -> SwarmBuilder<Tokio, BuildPhase<T, B>>

pub fn build(self) -> Swarm<B>
where B: NetworkBehaviour, T: AuthenticatedMultiplexedTransport,

Source

impl SwarmBuilder<Tokio, TcpPhase>

pub fn with_tcp<SecUpgrade, SecStream, SecError, MuxUpgrade, MuxStream, MuxError>( self, tcp_config: Config, security_upgrade: SecUpgrade, multiplexer_upgrade: MuxUpgrade, ) -> Result<SwarmBuilder<Tokio, QuicPhase<impl AuthenticatedMultiplexedTransport>>, <SecUpgrade as IntoSecurityUpgrade<TcpStream>>::Error>
where SecStream: AsyncRead + AsyncWrite + Unpin + Send + 'static, SecError: Error + Send + Sync + 'static, SecUpgrade: IntoSecurityUpgrade<TcpStream>, <SecUpgrade as IntoSecurityUpgrade<TcpStream>>::Upgrade: InboundConnectionUpgrade<Negotiated<TcpStream>, Output = (PeerId, SecStream), Error = SecError> + OutboundConnectionUpgrade<Negotiated<TcpStream>, Output = (PeerId, SecStream), Error = SecError> + Clone + Send + 'static, <<SecUpgrade as IntoSecurityUpgrade<TcpStream>>::Upgrade as InboundConnectionUpgrade<Negotiated<TcpStream>>>::Future: Send, <<SecUpgrade as IntoSecurityUpgrade<TcpStream>>::Upgrade as OutboundConnectionUpgrade<Negotiated<TcpStream>>>::Future: Send, <<<SecUpgrade as IntoSecurityUpgrade<TcpStream>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<SecUpgrade as IntoSecurityUpgrade<TcpStream>>::Upgrade as UpgradeInfo>::Info: Send, MuxStream: StreamMuxer + Send + 'static, <MuxStream as StreamMuxer>::Substream: Send + 'static, <MuxStream as StreamMuxer>::Error: Send + Sync + 'static, MuxUpgrade: IntoMultiplexerUpgrade<SecStream>, <MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade: InboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + OutboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + Clone + Send + 'static, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as InboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as OutboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, MuxError: Error + Send + Sync + 'static, <<<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::Info: Send,

Adds a TCP based transport.

Note that both security_upgrade and multiplexer_upgrade take function pointers, i.e. they take the function themselves (without the invocation via ()), not the result of the function invocation. See example below.

let swarm = SwarmBuilder::with_new_identity()
    .with_tokio()
    .with_tcp(
        Default::default(),
        (libp2p_tls::Config::new, libp2p_noise::Config::new),
        libp2p_yamux::Config::default,
    )?
Source

impl SwarmBuilder<Tokio, TcpPhase>

pub fn with_quic( self, ) -> SwarmBuilder<Tokio, OtherTransportPhase<impl AuthenticatedMultiplexedTransport>>

Source

impl SwarmBuilder<Tokio, TcpPhase>

pub fn with_quic_config( self, constructor: impl FnOnce(Config) -> Config, ) -> SwarmBuilder<Tokio, OtherTransportPhase<impl AuthenticatedMultiplexedTransport>>

Source

impl<Provider> SwarmBuilder<Provider, TcpPhase>

pub fn with_other_transport<Muxer, OtherTransport, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, OtherTransportPhase<impl AuthenticatedMultiplexedTransport>>, <R as TryIntoTransport<OtherTransport>>::Error>
where Muxer: StreamMuxer + Send + 'static, OtherTransport: Transport<Output = (PeerId, Muxer)> + Send + Unpin + 'static, R: TryIntoTransport<OtherTransport>, <OtherTransport as Transport>::Error: Send + Sync + 'static, <OtherTransport as Transport>::Dial: Send, <OtherTransport as Transport>::ListenerUpgrade: Send, <Muxer as StreamMuxer>::Substream: Send, <Muxer as StreamMuxer>::Error: Send + Sync,

Source

impl SwarmBuilder<Tokio, TcpPhase>

pub async fn with_websocket<SecUpgrade, SecStream, SecError, MuxUpgrade, MuxStream, MuxError>( self, security_upgrade: SecUpgrade, multiplexer_upgrade: MuxUpgrade, ) -> Result<SwarmBuilder<Tokio, RelayPhase<impl AuthenticatedMultiplexedTransport>>, WebsocketError<<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Error>>
where SecStream: AsyncRead + AsyncWrite + Unpin + Send + 'static, SecError: Error + Send + Sync + 'static, SecUpgrade: IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>, <SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade: InboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>, Output = (PeerId, SecStream), Error = SecError> + OutboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>, Output = (PeerId, SecStream), Error = SecError> + Clone + Send + 'static, <<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as InboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>>>::Future: Send, <<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as OutboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>>>::Future: Send, <<<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as UpgradeInfo>::Info: Send, MuxStream: StreamMuxer + Send + 'static, <MuxStream as StreamMuxer>::Substream: Send + 'static, <MuxStream as StreamMuxer>::Error: Send + Sync + 'static, MuxUpgrade: IntoMultiplexerUpgrade<SecStream>, <MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade: InboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + OutboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + Clone + Send + 'static, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as InboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as OutboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, MuxError: Error + Send + Sync + 'static, <<<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::Info: Send,

Source

impl<T> SwarmBuilder<Tokio, WebsocketPhase<T>>

Adds a websocket client transport.

Note that both security_upgrade and multiplexer_upgrade take function pointers, i.e. they take the function themselves (without the invocation via ()), not the result of the function invocation. See example below.

let swarm = SwarmBuilder::with_new_identity()
    .with_tokio()
    .with_websocket(
        (libp2p_tls::Config::new, libp2p_noise::Config::new),
        libp2p_yamux::Config::default,
    )
    .await?
pub async fn with_websocket<SecUpgrade, SecStream, SecError, MuxUpgrade, MuxStream, MuxError>( self, security_upgrade: SecUpgrade, multiplexer_upgrade: MuxUpgrade, ) -> Result<SwarmBuilder<Tokio, RelayPhase<impl AuthenticatedMultiplexedTransport>>, WebsocketError<<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Error>>
where T: AuthenticatedMultiplexedTransport, SecStream: AsyncRead + AsyncWrite + Unpin + Send + 'static, SecError: Error + Send + Sync + 'static, SecUpgrade: IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>, <SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade: InboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>, Output = (PeerId, SecStream), Error = SecError> + OutboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>, Output = (PeerId, SecStream), Error = SecError> + Clone + Send + 'static, <<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as InboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>>>::Future: Send, <<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as OutboundConnectionUpgrade<Negotiated<RwStreamSink<BytesConnection<TcpStream>>>>>::Future: Send, <<<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<SecUpgrade as IntoSecurityUpgrade<RwStreamSink<BytesConnection<TcpStream>>>>::Upgrade as UpgradeInfo>::Info: Send, MuxStream: StreamMuxer + Send + 'static, <MuxStream as StreamMuxer>::Substream: Send + 'static, <MuxStream as StreamMuxer>::Error: Send + Sync + 'static, MuxUpgrade: IntoMultiplexerUpgrade<SecStream>, <MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade: InboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + OutboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + Clone + Send + 'static, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as InboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as OutboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, MuxError: Error + Send + Sync + 'static, <<<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::Info: Send,

Source

impl<T, Provider> SwarmBuilder<Provider, WebsocketPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_relay_client<SecUpgrade, SecStream, SecError, MuxUpgrade, MuxStream, MuxError>( self, security_upgrade: SecUpgrade, multiplexer_upgrade: MuxUpgrade, ) -> Result<SwarmBuilder<Provider, BandwidthMetricsPhase<impl AuthenticatedMultiplexedTransport, Behaviour>>, <SecUpgrade as IntoSecurityUpgrade<Connection>>::Error>
where SecStream: AsyncRead + AsyncWrite + Unpin + Send + 'static, SecError: Error + Send + Sync + 'static, SecUpgrade: IntoSecurityUpgrade<Connection>, <SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade: InboundConnectionUpgrade<Negotiated<Connection>, Output = (PeerId, SecStream), Error = SecError> + OutboundConnectionUpgrade<Negotiated<Connection>, Output = (PeerId, SecStream), Error = SecError> + Clone + Send + 'static, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as InboundConnectionUpgrade<Negotiated<Connection>>>::Future: Send, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as OutboundConnectionUpgrade<Negotiated<Connection>>>::Future: Send, <<<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<SecUpgrade as IntoSecurityUpgrade<Connection>>::Upgrade as UpgradeInfo>::Info: Send, MuxStream: StreamMuxer + Send + 'static, <MuxStream as StreamMuxer>::Substream: Send + 'static, <MuxStream as StreamMuxer>::Error: Send + Sync + 'static, MuxUpgrade: IntoMultiplexerUpgrade<SecStream>, <MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade: InboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + OutboundConnectionUpgrade<Negotiated<SecStream>, Output = MuxStream, Error = MuxError> + Clone + Send + 'static, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as InboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as OutboundConnectionUpgrade<Negotiated<SecStream>>>::Future: Send, MuxError: Error + Send + Sync + 'static, <<<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::InfoIter as IntoIterator>::IntoIter: Send, <<MuxUpgrade as IntoMultiplexerUpgrade<SecStream>>::Upgrade as UpgradeInfo>::Info: Send,

Source

impl<Provider, T> SwarmBuilder<Provider, WebsocketPhase<T>>
where T: AuthenticatedMultiplexedTransport,

pub fn with_behaviour<B, R>( self, constructor: impl FnOnce(&Keypair) -> R, ) -> Result<SwarmBuilder<Provider, SwarmPhase<T, B>>, <R as TryIntoBehaviour<B>>::Error>
where R: TryIntoBehaviour<B>,